package App::ImapNotify::Notifier;
use v5.24;
use strict;
use warnings;

use Function::Parameters;

=head1 NAME

App::ImapNotify::Notifier - Show notification to user

=head1 SYNOPSIS

  use App::ImapNotify::Notifier;

  my $notifier = App::ImapNotify::Notifier->new();
  $notifier->notify("subject", "body");

=head1 DESCRIPTION

Uses notify-send to show a notification to the user.

=head1 SEE ALSO

L<App::ImapNotify>

=cut

method new($class: $deps = {}) {
	return $class->new_no_defaults($deps);
}

method new_no_defaults($class: $deps = {}) {
	my $self = {};
	bless $self, $class;
	$self->{deps} = $deps;
	return $self;
}

method notify($heading, $body) {
	system(qw(notify-send -t 10000 --), $heading, $body);
}



1;

__END__
