use strict;
use warnings;
use Test::Differences;
use Test::More;
use Test::MockObject;

use Log::Any::Adapter ('Stderr', log_level => "warn");

use App::ImapNotify;
use App::ImapNotify::ImapClient;


my $notifier = Test::MockObject->new();
$notifier->set_true("notify");

my $socket = Test::MockObject->new();
$socket->set_series('readline',
	"* OK [CAPABILITY IMAP4rev1 SASL-IR LOGIN-REFERRALS ID ENABLE IDLE LITERAL+ AUTH=PLAIN AUTH=LOGIN] Fake server ready.\r\n",
	"CMD-0 OK [CAPABILITY IMAP4rev1 SASL-IR LOGIN-REFERRALS ID ENABLE IDLE SORT SORT=DISPLAY THREAD=REFERENCES THREAD=REFS THREAD=ORDEREDSUBJECT MULTIAPPEND URL-PARTIAL CATENATE UNSELECT CHILDREN NAMESPACE UIDPLUS LIST-EXTENDED I18NLEVEL=1 CONDSTORE QRESYNC ESEARCH ESORT SEARCHRES WITHIN CONTEXT=SEARCH LIST-STATUS BINARY MOVE SNIPPET=FUZZY LITERAL+ NOTIFY SPECIAL-USE COMPRESS=DEFLATE] Logged in\r\n",
	"CMD-1 OK [READ-WRITE] Select completed (0.001 + 0.000 secs).\r\n",
	"CMD-2 OK NOTIFY completed (0.001 + 0.000 secs).\r\n",
	# this stuff should be ignored
	"* 51 EXISTS\r\n",
	"* 1 RECENT\r\n",
	# this is a notification
	"* 51 FETCH (UID 41023 BODY[HEADER.FIELDS (FROM TO SUBJECT)] {".(36+24+23+2)."}\r\n",
	"From: <test\@localhost.localdomain>\r\n",
	"To: <bluewind\@xinu.at>\r\n",
	"Subject: Some subject\r\n",
	"\r\n",
	")\r\n",
);

$socket->set_true(qw(writeline));

my $config = {
	log_id => 'test-id1',
	host => 'localhost.localdomain',
	port => 993,
	username => 'tester1',
	password => 'secretPW42',
	mailboxes => [qw(INBOX INBOX.test)],
	keepalive_timeout => 300,
};

my $imap_client = App::ImapNotify::ImapClient->new_no_defaults($config, {sock => $socket});

my $app = App::ImapNotify->new_no_defaults($config, {imap_client => $imap_client, notifier => $notifier});

$app->loop();

is($socket->readline(), undef, "readline queue is read fully");

eq_or_diff($notifier->_calls(), [
		['notify', [$notifier, 'From: <test@localhost.localdomain>', 'Subject: Some subject']]
	], "notifier is called correctly");

done_testing;
